<?php
require_once(WCF_DIR.'lib/form/AbstractSecureForm.class.php');
require_once(WCF_DIR.'lib/data/user/User.class.php');

class TimeBanForm extends AbstractSecureForm  {
    
    public $templateName = 'timeBan';
    public $neededPermissions = 'admin.user.canBanUser';
	
	public $duration; 
	
	public $reason; 
	
	public $userID; 
	
    public function readFormParameters() {
        parent::readFormParameters();

        $this->duration = (isset($_POST['duration'])) ? intval($_POST['duration']) : null; 
        $this->reason = (isset($_POST['reason'])) ? StringUtil::trim($_POST['reason']) : ""; 
		
    }
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		$this->userID = (isset($_GET['userID']) && !empty($_GET['userID'])) ? intval($_GET['userID']) : null; 
	}
	
    public function readData() {
        parent::readData();
		
        $this->validateUser(); 
    }
    
    /**
     * @see Form::validate()
     */
    public function validate() {
        parent::validate(); 
  
        if ($this->duration === null || ($this->duration + TIME_NOW) <= TIME_NOW) {
            throw new UserInputException('duration', 'notValid'); 
        }
        
        $this->validateUser(); 
    }
    
    public function validateUser() {
        if ($this->userID === null) {
            throw new IllegalLinkException();
        }
        
        if ($this->userID == WCF::getUser()->userID) {
            throw new NamedUserException(WCF::getLanguage()->get('wcf.user.timeBan.error.selfBan'));
        }
        
        $this->user = new User($this->userID); 
        
		// check permissions
		$sql = "SELECT	DISTINCT groupID
				FROM	wcf".WCF_N."_user_to_groups
				WHERE	userID = ".$this->user->userID;
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			if (!Group::isAccessibleGroup($row['groupID'])) {
				throw new PermissionDeniedException();
			}
		}
		
        if ($this->user->userID === 0) {
            throw new IllegalLinkException(); 
        }
        
        if ($this->user->banned == 1) {
            throw new NamedUserException(WCF::getLanguage()->get('wcf.user.timeBan.error.alreadyBanned'));
        }
    }
    
    /**
     * @see Form::save()
     */
    public function save() {
        parent::save();

        $sql = "UPDATE	wcf".WCF_N."_user
			SET	banned = 1, 
                                banReason = '". escapeString($this->reason) ."'
			WHERE	userID = ".$this->user->userID;
        WCF::getDB()->sendQuery($sql);
		
		$expired = TIME_NOW + $this->duration; 
        
        $sql = "INSERT INTO wcf".WCF_N."_user_timebans 
                        (userID, expired)
                    VALUES
                        (". $this->user->userID .", ". (int) $expired  .")"; 
        WCF::getDB()->sendQuery($sql);
        
        $this->saved();

        // forward to index page
        WCF::getTPL()->assign(array(
                'url' => 'index.php?page=User&userID='.$this->user->userID.SID_ARG_1ST,
                'message' => WCF::getLanguage()->get('wcf.acp.user.ban.success')
        ));
        WCF::getTPL()->display('redirect');
        exit;
    }
    
    /**
     * @see Page::assignVariables()
     */
    public function assignVariables() {
        parent::assignVariables();
        
        WCF::getTPL()->assign(array(
                'user' => $this->user
        ));
    }
}